Please follow these pull request guidelines:

1. Update your fork to the latest upstream version.

2. Follow the coding conventions of the original source files (indentation, spaces, brackets layout).

3. Code changes must pass JSHint validation with the `.jshintrc` settings of this project.

4. Code changes must pass the QUnit tests defined in the `test` folder.

5. New features should be covered by accompanying QUnit tests.

6. Keep your commits as atomic as possible, i.e. create a new commit for every single bug fix or feature added.

7. Always add meaningful commit messages.
